@@ -2,7 +2,7 @@
 // File: check.js
 // Product: BASrouterLX
 // Author: Harpartap Parmar
-// Copyright 2013: Contemporary Control Systems, Inc.
+// Copyright 2018: Contemporary Control Systems, Inc.
 //
 function checkDigit(val)
 {
@@ -90,7 +90,7 @@ function NumberCheck(value, a, b)
 	}
 	if(proceed==0)
 	{
-		if((value<a) || (value >b))
+		if((parseInt(value,10) < parseInt(a, 10)) || (parseInt(value,10) > parseInt(b,10)))
 		{
 			return 2; 
 		}
@@ -267,6 +267,8 @@ function checkSetupPage(a)
 		return false; 
 	}
 
+	eth_nw=val;
+
 	// BACnet/IP UDP Port 1
 	val=a._1_6_0_1.value;
 	if(val.length==0)
@@ -317,7 +319,7 @@ function checkSetupPage(a)
 		a._1_6_0_1.focus();
 		return false;
 	}
-
+	bac_ip_nw1=val;
 
 	// IP Address _1_8_0_1
 	ipVal=a._1_8_0_1.value
@@ -532,6 +534,32 @@ function checkSetupPage(a)
 		a._1_12_0_2.focus();
 		return false; 
 	}
+	mstp_nw=val;
+
+	//
+	//Check for duplicate network numbers
+	if( (eth_nw != 0) && (bac_ip_nw1 != 0) && (eth_nw == bac_ip_nw1))
+	{
+		alert('Duplicate values for Ethernet Network and BACnet/IP Network 1');
+		a._1_5_0_2.focus();
+		return false; 
+	}
+
+	if( (eth_nw != 0) && (mstp_nw != 0) && (eth_nw == mstp_nw))
+	{
+		alert('Duplicate values for Ethernet Network and MS/TP Network');
+		a._1_7_0_2.focus();
+		return false; 
+	}
+	
+	if( (bac_ip_nw1 != 0) && (mstp_nw != 0) && (bac_ip_nw1 == mstp_nw))
+	{
+		alert('Duplicate values for BACnet/IP Network 1 and MS/TP Network');
+		a._1_7_0_2.focus();
+		return false; 
+	}
+	// end duplicate network number check
+	//
 
 	// Max Masters
 	val=a._1_13_0_2.value;
@@ -541,7 +569,7 @@ function checkSetupPage(a)
 		a._1_13_0_2.focus();
 		return false;
 	}
-	ret=NumberCheck(val, 0, 127);
+	ret=NumberCheck(val, 1, 127);
 	if(ret==1)
 	{
 		alert('Input numerical value for Max Masters');
@@ -550,7 +578,7 @@ function checkSetupPage(a)
 	}
 	if(ret==2)
 	{
-		alert('Max Masters value should be between 0 and 127');
+		alert('Max Masters value should be between 1 and 127');
 		a._1_13_0_2.focus();
 		return false; 
 	}
@@ -600,7 +628,7 @@ function checkTimePage(a)
 	ret=NumberCheck(val, 1000, 9999);
 	if(ret==1)
 	{
-		alert('Input numerical value for Year');
+		alert('Input valid numerical value for Year');
 		a._9_1_0_2.focus();
 		return false;
 	}
@@ -944,27 +972,39 @@ function checkPasswordPage(a)
 	var u=a._11_1_1_1.value;
 	var p1=a._11_1_2_1.value;
 	var p2=a._11_1_3_1.value;
+	var paswd=  /^(?=.*[0-9])(?=.*[a-zA-Z])/;
 
-	if ( ( /[^A-Za-z0-9]/.test(u) ) || ( /[^A-Za-z0-9]/.test(p1) ) )
+	if ( ( /[^A-Za-z0-9]/.test(u) ) || ( /[^A-Za-z0-9!%@#\+\^\[\]_{}~]+$/.test(p1) ) )
 	{ 
-		alert('Only alpha-numeric characters can be used for Username and Password.');
+		alert('Only alpha-numeric characters can be used for Username.\nAlpha-numeric and special characters ~ ! @ # % ^ + [ ] { } and _ can be used for Password.');
 		return false;
 	}
 
-	//check for minimum length of 5 characters
-	if( (u.length < 5) || (p1.length < 5) || (p2.length < 5) )
+	//check for minimum length of 8 characters
+	if( (u.length < 8) || (p1.length < 8) || (p2.length < 8) )
 	{
-		alert('Username and Password must be atleast 5 characters long.');
+		alert('Username and Password must be atleast 8 characters long.');
 		return false;
 	}
 
 	//check to see if passwords p1 and p2 match	
 	if(p1 != p2)
 	{
-		alert('Passwords entered do not match. Re-enter passwords and try again');
+		alert('Passwords entered do not match. Re-enter passwords and try again.');
 		return false;	
 	}
 
+	if(p1.match(paswd)) 
+	{ 
+		
+		return true;
+	}
+	else
+	{
+		alert('Password must contain atleast one alphabet and one number.');
+		return false;
+	}
+
 	return true;
 }
 
@@ -1940,4 +1980,12 @@ function checkWhitelistPage(a)
 		retVal=wlcheck10(a);if(retVal==false) return false;
 	}
 	return true;
-}
\ No newline at end of file
+}
+
+//
+//
+function DisableViewMSTPfile(a)
+{
+	document.getElementById("viewMSTP_button").disabled = true;
+	document.getElementById("viewMSTP_button").value="Please Wait ...";
+}
